#
# spec file for package ghc-wai-extra
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name wai-extra
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        3.0.21.0
Release:        lp150.5.1
Summary:        Provides some basic WAI handlers and middleware
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cookie-devel
BuildRequires:  ghc-data-default-class-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-fast-logger-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-iproute-devel
BuildRequires:  ghc-lifted-base-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-streaming-commons-devel
BuildRequires:  ghc-stringsearch-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-compat-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-vault-devel
BuildRequires:  ghc-void-devel
BuildRequires:  ghc-wai-devel
BuildRequires:  ghc-wai-logger-devel
BuildRequires:  ghc-word8-devel
BuildRequires:  ghc-zlib-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
Provides basic WAI handler and middleware functionality:

* WAI Testing Framework

Hspec testing facilities and helpers for WAI.

* Event Source/Event Stream

Send server events to the client. Compatible with the JavaScript EventSource
API.

* Accept Override

Override the Accept header in a request. Special handling for the _accept query
parameter (which is used throughout WAI override the Accept header).

* Add Headers

WAI Middleware for adding arbitrary headers to an HTTP request.

* Clean Path

Clean a request path to a canonical form.

* GZip Compression

Negotiate HTTP payload gzip compression.

* HTTP Basic Authentication

WAI Basic Authentication Middleware which uses Authorization header.

* JSONP

"JSON with Padding" middleware. Automatic wrapping of JSON responses to convert
into JSONP.

* Method Override / Post

Allows overriding of the HTTP request method via the _method query string
parameter.

* Request Logging

Request logging middleware for development and production environments

* Request Rewrite

Rewrite request path info based on a custom conversion rules.

* Stream Files

Convert ResponseFile type responses into ResponseStream type.

* Virtual Host

Redirect incoming requests to a new host based on custom rules.

API docs and the README are available at
<http://www.stackage.org/package/wai-extra>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md example

%changelog
* Fri Dec 29 2017 psimons@suse.com
- Update to version 3.0.21.0.
  A more detailed change log is not available.
* Mon Dec  4 2017 psimons@suse.com
- Update to version 3.0.20.2.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jun 25 2017 psimons@suse.com
- Update to version 3.0.20.0.
* Thu Jan 26 2017 psimons@suse.com
- Update to version 3.0.19.1 with cabal2obs.
* Thu Oct 27 2016 psimons@suse.com
- Update to version 3.0.19 with cabal2obs.
* Sat Oct  1 2016 psimons@suse.com
- Update to version 3.0.18 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 3.0.17 revision 0 with cabal2obs.
* Mon Jul 18 2016 psimons@suse.com
- Update to version 3.0.16.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 mimi.vx@gmail.com
- update to 3.0.16.1
  * Fix the way the header length is checked (for limiting the max header length)
  * Add a new function "parseRequestBodyEx" that allows various size limits to be set.
* Fri Jun 17 2016 mimi.vx@gmail.com
- update to 3.0.15.2
  * Doc improvements
* Tue Apr 26 2016 mimi.vx@gmail.com
- update to 3.0.15.1
  * don't use deprecated CRT functions on Windows
* Wed Mar 23 2016 mimi.vx@gmail.com
- update to 3.0.15
  * add requestSizeCheck
* Fri Mar 18 2016 mimi.vx@gmail.com
- update to 3.0.14.3
  * Add missing requestHeaderReferer and requestHeaderUserAgent fields to CGI
  * Case insensitive multipart request header lookup
* Tue Mar  8 2016 mimi.vx@gmail.com
- update to 3.0.14.1
  * Doc update for logStdout and logStdoutDev
* Fri Jan 15 2016 mimi.vx@gmail.com
- update to 3.0.14
  * Middleware to force domain names.
* Thu Dec 31 2015 mimi.vx@gmail.com
- update to 3.0.13.1
  * support wai 3.2
* Sun Nov 22 2015 mimi.vx@gmail.com
- update to 3.0.13
  * Autoflush handle
  * Add Network.Wai.Header.contentLength to read the Content-Length header
    of a response
  * The gzip middleware no longer zips responses smaller than 860 bytes
* Mon Oct 12 2015 mimi.vx@gmail.com
- update to 3.0.11.1
  * Add constructor for more detailed custom output formats for RequestLogger
  * Add JSON output formatter for RequestLogger
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 3.0.10
  * Network.Wai.Middleware.Routed module added
  * Adding Request Body to RequestLogger
* Mon Jul 13 2015 mimi.vx@gmail.com
- update to 3.0.8.2
* Mon Apr 27 2015 mimi.vx@gmail.com
- update to 3.0.7.1
  * no upstream changelog
* Fri Apr 24 2015 mimi.vx@gmail.com
- initial commit
